@@ -30,11 +30,14 @@ class SyAdvServer : public QObject
  public:
   enum AdvertType {Type0=0,Type1=1,Type2=2,TypeLast=3};
   SyAdvServer(SyRouting *r,bool read_only=false,QObject *parent=0);
+  ~SyAdvServer();
 
  private slots:
   void readData();
   void expireData();
-  void sendData();
+  void sendAdvert0Data();
+  void sendAdvert1Data();
+  void sendAdvert2Data();
   void saveSourcesData();
 
  private:
@@ -44,12 +47,11 @@ class SyAdvServer : public QObject
   SyAdvSource *GetSource(const QHostAddress &node_addr,unsigned slot);
   int TagIsSource(const SyTag *tag) const;
   void ScheduleSourceSave();
-  double GetTimestamp() const;
   SyMcastSocket *ctrl_advert_socket;
-  QTimer *ctrl_advert_timer;
+  QTimer *ctrl_advert_timer0;
+  QTimer *ctrl_advert_timer1;
+  QTimer *ctrl_advert_timer2;
   uint32_t ctrl_advert_seqno;
-  double ctrl_advert_timestamp;
-  AdvertType ctrl_advert_type;
   SyRouting *adv_routing;
   QTimer *ctrl_expire_timer;
   QTimer *ctrl_savesources_timer;
