@@ -118,9 +118,8 @@ bool SyLwrpServer::ExecuteLogin(int id,QStringList &args)
 bool SyLwrpServer::ExecuteVer(int id,QStringList &args)
 {
   SendCommand(id,QString().
-     sprintf("VER LWRP:%s DEVN:\"%s\" SYSV:%s NSRC:%u/2 NDST:%u NGPI:%u NGPO:%u",
-	     SWITCHYARD_PROTOCOL_VERSION,SWITCHYARD_DEVICE_NAME,
-	     SWITCHYARD_VERSION,
+    sprintf("VER LWRP:%s DEVN:\"%s\" SYSV:%s NSRC:%u/2 NDST:%u NGPI:%u NGPO:%u",
+	     SWITCHYARD_LWRP_VERSION,SWITCHYARD_DEVICE_NAME,VERSION,
 	     ctrl_routing->srcSlots(),ctrl_routing->dstSlots(),
 	     ctrl_routing->gpis(),ctrl_routing->gpos()));
   return true;
@@ -356,6 +355,24 @@ bool SyLwrpServer::ExecuteGpo(int ch,QStringList &args)
 }
 
 
+bool SyLwrpServer::ExecuteIfc(int ch,QStringList &args)
+{
+  if(args.size()>2) {
+    return false;
+  }
+  if(args.size()==2) {
+    QHostAddress addr(args[1]);
+    if(addr.isNull()) {
+      return false;
+    }
+    ctrl_routing->setNicAddress(addr);
+  }
+  SendCommand(ch,"IFC "+ctrl_routing->nicAddress().toString());
+
+  return true;
+}
+
+
 QString SyLwrpServer::SrcLine(int slot)
 {
   return QString().
@@ -462,6 +479,9 @@ void SyLwrpServer::ParseCommand(int id)
   if(args[0]=="gpo") {
     ok=ExecuteGpo(id,args);
   }
+  if(args[0]=="ifc") {
+    ok=ExecuteIfc(id,args);
+  }
   if(!ok) {
     SendCommand(id,"ERROR 1000 bad command");
   }
